@@ -1,6 +1,7 @@
 
 class PaymentInstrumentType():
     PayPalAccount = "paypal_account"
+    PayPalHere = "paypal_here"
     EuropeBankAccount = "europe_bank_account"
     CreditCard = "credit_card"
     CoinbaseAccount = "coinbase_account"
@@ -12,3 +13,4 @@ class PaymentInstrumentType():
     VisaCheckoutCard = "visa_checkout_card"
     MasterpassCard = "masterpass_card"
     SamsungPayCard = "samsung_pay_card"
+    LocalPayment = "local_payment"
